"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  ExtrinsicStatus: () => ExtrinsicStatus,
  createExtrinsicEventHandler: () => createExtrinsicEventHandler,
  createTxEventHandler: () => createTxEventHandler,
  getPolkadotApi: () => getPolkadotApi,
  hasDecimalOverflow: () => hasDecimalOverflow,
  toBigInt: () => toBigInt,
  toDecimal: () => toDecimal
});
module.exports = __toCommonJS(src_exports);

// src/api/polkadot.api.ts
var import_api = require("@polkadot/api");
var import_lru_cache = __toESM(require("lru-cache"), 1);
var cache = new import_lru_cache.default({
  max: 20,
  dispose: async (promise) => {
    const api = await promise;
    if (api.isConnected) {
      api.disconnect();
    }
  }
});
async function getPolkadotApi(ws, onDisconnect) {
  const promise = cache.get(ws) || import_api.ApiPromise.create({
    provider: new import_api.WsProvider(ws)
  });
  cache.set(ws, promise);
  const api = await promise;
  await api.isReady;
  if (onDisconnect) {
    api.once("disconnected", onDisconnect);
  }
  return api;
}

// src/handlers/handlers.interfaces.ts
var ExtrinsicStatus = /* @__PURE__ */ ((ExtrinsicStatus2) => {
  ExtrinsicStatus2["Failed"] = "Failed";
  ExtrinsicStatus2["Sent"] = "Sent";
  ExtrinsicStatus2["Success"] = "Success";
  return ExtrinsicStatus2;
})(ExtrinsicStatus || {});

// src/handlers/createExtrinsicEventHandler.ts
function createExtrinsicEventHandler(pallet, successEvent, cb) {
  return ({ events = [], status, txHash }) => {
    const hash = txHash.toHex();
    if (status.isReady) {
      cb({ status: "Sent" /* Sent */, txHash: hash });
    }
    if (status.isInBlock) {
      const block = status.asInBlock.toString();
      events.forEach(({ event: { data, method, section } }) => {
        var _a;
        if (section === pallet && method === successEvent) {
          if (method === "Attempted") {
            const eventData = data.at(0);
            if (eventData.isIncomplete) {
              cb({
                status: "Failed" /* Failed */,
                blockHash: block,
                txHash: hash,
                message: (_a = eventData.asIncomplete) == null ? void 0 : _a.toHuman().join("; ")
              });
              return;
            }
          }
          cb({
            status: "Success" /* Success */,
            blockHash: block,
            txHash: hash
          });
        }
        if (section === "system" && method === "ExtrinsicFailed") {
          cb({
            status: "Failed" /* Failed */,
            blockHash: block,
            txHash: hash,
            message: data.join("; ")
          });
        }
      });
    }
  };
}

// src/handlers/createTxEventHandler.ts
async function createTxEventHandler(ethersSigner, txHash, cb, skipSentEvent = false) {
  if (!ethersSigner.provider) {
    throw new Error("options.ethersSigner has not provider");
  }
  if (!skipSentEvent) {
    cb({ status: "Sent" /* Sent */, txHash });
  }
  const tx = await ethersSigner.provider.getTransactionReceipt(txHash);
  if (!tx) {
    setTimeout(
      () => createTxEventHandler(ethersSigner, txHash, cb, true),
      2e3
    );
    return;
  }
  if (tx.status === 1) {
    cb({
      status: "Success" /* Success */,
      blockHash: tx.blockHash,
      txHash
    });
  } else {
    cb({
      status: "Failed" /* Failed */,
      blockHash: tx.blockHash,
      txHash
    });
  }
}

// src/numbers/decimals.ts
var import_big = __toESM(require("big.js"), 1);
function toDecimal(number, decimals, maxDecimal = 6, roundType) {
  const dividend = (0, import_big.default)(number.toString().replace(/[^0-9]/g, ""));
  const divisor = (0, import_big.default)(10).pow(decimals);
  const result = dividend.div(divisor).round(maxDecimal, roundType);
  return result;
}
function toBigInt(amount, decimals) {
  const multiplier = (0, import_big.default)(10).pow(decimals);
  const result = (0, import_big.default)(amount).mul(multiplier);
  return BigInt(result.toFixed(0, import_big.default.roundDown));
}
function hasDecimalOverflow(fl, maxDecimal) {
  const parts = fl.toString().split(".");
  return parts.length > 1 && parts[1].length > maxDecimal;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  ExtrinsicStatus,
  createExtrinsicEventHandler,
  createTxEventHandler,
  getPolkadotApi,
  hasDecimalOverflow,
  toBigInt,
  toDecimal
});
//# sourceMappingURL=index.cjs.map